# Be sure to restart your server when you modify this file.

# Your secret key for verifying the integrity of signed cookies.
# If you change this key, all old signed cookies will become invalid!
# Make sure the secret is at least 30 characters and all random,
# no regular words or you'll be exposed to dictionary attacks.
Dummy::Application.config.secret_token = '16930c8df0e323d059e1801bc59c7674266cd15aac547bcfed32712b162293623eecfad27b19413062914302b1b6ba96ade16d15c5e59bdb3e43e7b1c1bf48a9'
